=============================
django-gaekit
=============================

Collection of backends, wrappers and utilities to enquicken django development on Google App Engine.

.. image:: https://travis-ci.org/Beyond-Digital/django-gaekit.svg?branch=master
        :target: https://travis-ci.org/Beyond-Digital/django-gaekit

.. image:: https://pypip.in/version/django-gaekit/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/django-gaekit/
    :alt: Latest Version

.. image:: https://requires.io/github/Beyond-Digital/django-gaekit/requirements.svg?branch=master
     :target: https://requires.io/github/Beyond-Digital/django-gaekit/requirements/?branch=master
     :alt: Requirements Status


Documentation
-------------

The full documentation is at http://django-gaekit.rtfd.org.

Features
--------

* Django storage backend using Google Cloud Storage
* Django cache backend using Memcache
* Import blacklisted modules in the SDK (eg sqlite3)
